<?php
/**
 * Bulgarian language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Nikolay Vladimirov <nikolay@vladimiroff.com>
 */
$lang['encoding']                = 'utf-8';
$lang['direction']               = 'ltr';
$lang['doublequoteopening']      = '“';
$lang['doublequoteclosing']      = '”';
$lang['singlequoteopening']      = '‘';
$lang['singlequoteclosing']      = '’';
$lang['btn_edit']                = 'Редактиране';
$lang['btn_source']              = 'Показване на кода на страницата';
$lang['btn_show']                = 'Показване на страницата';
$lang['btn_create']              = 'Създаване на страницата';
$lang['btn_search']              = 'Търсене';
$lang['btn_save']                = 'Запис';
$lang['btn_preview']             = 'Преглед';
$lang['btn_top']                 = 'Към началото';
$lang['btn_newer']               = '<< по-нови';
$lang['btn_older']               = 'по-стари >>';
$lang['btn_revs']                = 'История';
$lang['btn_recent']              = 'Последни промени';
$lang['btn_upload']              = 'Качване';
$lang['btn_cancel']              = 'Отказ';
$lang['btn_index']               = 'Индекс';
$lang['btn_secedit']             = 'Редактиране';
$lang['btn_login']               = 'Вход';
$lang['btn_logout']              = 'Изход';
$lang['btn_admin']               = 'Настройки';
$lang['btn_update']              = 'Обновяване';
$lang['btn_delete']              = 'Изтриване';
$lang['btn_back']                = 'Назад';
$lang['btn_backlink']            = 'Обратни връзки';
$lang['btn_backtomedia']         = 'Назад към избор на медиен файл';
$lang['btn_subscribe']           = 'Абониране за Промени';
$lang['btn_unsubscribe']         = 'Отписване от Промени';
$lang['btn_profile']             = 'Профил';
$lang['btn_reset']               = 'Изчистване';
$lang['btn_resendpwd']           = 'Пращане на нова парола';
$lang['btn_draft']               = 'Редактиране на чернова';
$lang['btn_recover']             = 'Възстановяване на чернова';
$lang['btn_draftdel']            = 'Изтриване на чернова';
$lang['loggedinas']              = 'Влезли сте като';
$lang['user']                    = 'Потребител';
$lang['pass']                    = 'Парола';
$lang['newpass']                 = 'Нова парола';
$lang['oldpass']                 = 'Потвърждение на текуща парола';
$lang['passchk']                 = 'oтново';
$lang['remember']                = 'Запомни ме';
$lang['fullname']                = 'Пълно име';
$lang['email']                   = 'Е-Поща';
$lang['register']                = 'Регистрация';
$lang['profile']                 = 'Потребителски профил';
$lang['badlogin']                = 'Потребителското име или паролата са грешни';
$lang['minoredit']               = 'Леки промени';
$lang['draftdate']               = 'Черновата бе автоматично записана на';
$lang['regmissing']              = 'Моля, попълнете всички полета.';
$lang['reguexists']              = 'Потребител с такова име вече съществува.';
$lang['regsuccess']              = 'Потребителят бе създаден и паролата е пратена по електронната поща.';
$lang['regsuccess2']             = 'Потребителят бе създаден.';
$lang['regmailfail']             = 'Изглежда, че има проблем с пращането на писмото с паролата. Моля, свържете се с администратора.';
$lang['regbadmail']              = 'Даденият адрес изглежда невалиден, ако мислите, че това е грешка - свържете се със администратора.';
$lang['regbadpass']              = 'Двете дадени пароли не са идентични, моля опитайте отново';
$lang['regpwmail']               = 'DokuWiki parola';
$lang['reghere']                 = 'Все още нямате профил? Просто си направете';
$lang['profna']                  = 'Това уики не поддържа промяна на профила';
$lang['profnochange']            = 'Няма промени.';
$lang['profnoempty']             = 'Празни име или електронна поща не са позволени.';
$lang['profchanged']             = 'Потребителският профил бе успешно обновен.';
$lang['pwdforget']               = 'Забравили сте си паролата? Вземете нова';
$lang['resendna']                = 'Това уики не поддържа повторно пращане на парола';
$lang['resendpwd']               = 'Пращане нова парола за';
$lang['resendpwdmissing']        = 'Моля, попълнете всички полета.';
$lang['resendpwdnouser']         = 'Потребителят не бе намерен в базата данни.';
$lang['resendpwdbadauth']        = 'Този код за потвърждение не е валиден. Проверете дали сте използвали целият адрес за потвърждение.';
$lang['resendpwdconfirm']        = 'Адрес за потвърждение бе пратен по електронната поща.';
$lang['resendpwdsuccess']        = 'Паролата ви бе пратена на електронната поща.';
$lang['txt_upload']              = 'Изберете файл за качване ';
$lang['txt_filename']            = 'Качване като(незадължително)';
$lang['txt_overwrt']             = 'Запис върху съществуващ файл';
$lang['lockedby']                = 'В момента е заключено от';
$lang['lockexpire']              = 'Затварянето изтича в';
$lang['willexpire']              = 'Затварянето на страницата за редактиране изтича след минута.\nЗа да избегнете противоречия използвайте бутонът, за да рестартирате броячът за затваряне.';
$lang['notsavedyet']             = 'Незапазените промени ще бъдат загубени.\nИскате ли да продължите?';
$lang['rssfailed']               = 'Имаше грешка при вземането на този източник(feed): ';
$lang['nothingfound']            = 'Нищо не бе намерено.';
$lang['mediaselect']             = 'Медийни файлове';
$lang['fileupload']              = 'Качване на медийни файлове';
$lang['uploadsucc']              = 'Качването бе успешно';
$lang['uploadfail']              = 'Качването бе неуспешно.Може би грешни права?';
$lang['uploadwrong']             = 'Качването бе отказано. Това файлово разширение е забранено!';
$lang['uploadexist']             = 'Файлът вече съществува. Нищо не бе направено.';
$lang['uploadbadcontent']        = 'Каченото съдържание на съответства на файлово разширение %s .';
$lang['uploadspam']              = 'Качването бе блокирано от черният списък за спам.';
$lang['uploadxss']               = 'Качването бе блокирано, заради възможно обидно съдържание.';
$lang['deletesucc']              = 'Файлът "%s" бе изтрит.';
$lang['deletefail']              = '"%s" не бе изтрит, проверете правата';
$lang['mediainuse']              = 'Файлът "%s" не бе изтрит - все още се ползва.';
$lang['namespaces']              = 'Именнипространсва';
$lang['mediafiles']              = 'Достъпни файлове в';
$lang['js']['keepopen']          = 'Задържане на прозореца отворен при избор';
$lang['js']['hidedetails']       = 'Скриване на детайлите';
$lang['mediausage']              = 'Използвайте следният синтаксис за да упоменете файлът:';
$lang['mediaview']               = 'Преглед на оригиналният файл';
$lang['mediaroot']               = 'root';
$lang['mediaupload']             = 'Качете файл в текущото именнопространство тук. За да създадете подименнипространства, добавете ги в началото на  "Качи като" име на файл разделени от двоеточие.';
$lang['mediaextchange']          = 'Разширението на файлът бе сменено от .%s на .%s!';
$lang['reference']               = 'References for';
$lang['ref_inuse']               = 'Файлът не може да бъде изтрит защото все още се ползва от следните страници:';
$lang['ref_hidden']              = 'Някои препратки са към страници, които нямате права да четете';
$lang['hits']                    = 'Съвпадения';
$lang['quickhits']               = 'Съвпадащи имена на страници';
$lang['toc']                     = 'Съдържание';
$lang['current']                 = 'текущо';
$lang['yours']                   = 'Вашата версия';
$lang['diff']                    = 'преглед на разликите с текущата версия';
$lang['line']                    = 'Ред';
$lang['breadcrumb']              = 'Следа';
$lang['youarehere']              = 'Вие сте тук';
$lang['lastmod']                 = 'Последна промяна';
$lang['by']                      = 'от';
$lang['deleted']                 = 'изтриване';
$lang['created']                 = 'създаване';
$lang['restored']                = 'старата версия възстановена';
$lang['external_edit']           = 'външна редакция';
$lang['summary']                 = 'Обобщение';
$lang['mail_newpage']            = 'dobavena stranica:';
$lang['mail_changed']            = 'promenenta stranica:';
$lang['mail_new_user']           = 'Nov potrebitel:';
$lang['mail_upload']             = 'kachen fail:';
$lang['js']['nosmblinks']              = "Връзките към Windows shares работят само под Internet Explorer.\nМожете да копирате и поставите връзката.";
$lang['qb_alert']                = 'Моля въведете текст за форматиране.\nЩе бъде добавен в края на документа.';
$lang['qb_bold']                 = 'Получер текст';
$lang['qb_italic']               = 'Курсив текст';
$lang['qb_underl']               = 'Подчертан текст';
$lang['qb_code']                 = 'Код';
$lang['qb_strike']               = 'Зачеркнат текст';
$lang['qb_h1']                   = 'Заглавие ниво 1';
$lang['qb_h2']                   = 'Заглавие ниво 2';
$lang['qb_h3']                   = 'Заглавие ниво 3';
$lang['qb_h4']                   = 'Заглавие ниво 4';
$lang['qb_h5']                   = 'Заглавие ниво 5';
$lang['qb_link']                 = 'Вътрешна препратка';
$lang['qb_extlink']              = 'Външна препратка';
$lang['qb_hr']                   = 'Хоризонтална линия';
$lang['qb_ol']                   = 'Подреден списък';
$lang['qb_ul']                   = 'Неподреден списък';
$lang['qb_media']                = 'Добавяне на картинки и други файлове';
$lang['qb_sig']                  = 'Вмъкване на подпис';
$lang['qb_smileys']              = 'Усмивчици';
$lang['qb_chars']                = 'Специални знаци';
$lang['del_confirm']             = 'Да бъдат ли изтрити избраните елементи?';
$lang['admin_register']          = 'Добабяне на нов потребител';
$lang['metaedit']                = 'Редактиране на метаданните';
$lang['metasaveerr']             = 'Запазването на метаданните не бе успешно';
$lang['metasaveok']              = 'Метаданните запазени';
$lang['img_backto']              = 'Назад към';
$lang['img_title']               = 'Заглавие';
$lang['img_caption']             = 'Описание';
$lang['img_date']                = 'Дата';
$lang['img_fname']               = 'Име на файл';
$lang['img_fsize']               = 'Размер';
$lang['img_artist']              = 'Фотограф';
$lang['img_copyr']               = 'Копирайт';
$lang['img_format']              = 'Формат';
$lang['img_camera']              = 'Камера';
$lang['img_keywords']            = 'Ключови думи';
$lang['subscribe_success']       = '%s бе добавен към абонамента за %s';
$lang['subscribe_error']         = 'Имаше грешка при добавянето на абонамента на %s за %s';
$lang['subscribe_noaddress']     = 'Няма адрес свързан с потребителят,не може да се абонирате';
$lang['unsubscribe_success']     = 'Абонаментът %s бе премахнат от списъка за %s';
$lang['unsubscribe_error']       = 'Имаше грешка при спирането на абонамента на %s от списъка %s';
$lang['authmodfailed']           = 'Лоша настройка на опознаването. Моля, уведомете администратора.';
$lang['authtempfail']            = 'Опознаването на потребителите е временно недостъпно. Ако това продължи дълго, моля уведомете администратора.';
$lang['i_chooselang']            = 'Избор на език';
$lang['i_installer']             = 'Инсталатор на DokuWiki';
$lang['i_wikiname']              = 'Име на уикито ';
$lang['i_enableacl']             = 'Включване на списъци за достъп(ACL) (препоръчително)';
$lang['i_superuser']             = 'Суперпотребител';
$lang['i_problems']              = 'Инсталатора намери проблеми указани по-долу. Не може да продължите докато не ги оправите';
$lang['i_modified']              = 'Поради мерки за сигурност този скрипт ще работи само с нова и непроменена Dokuwiki инсталация.
                         Трябва или да разархивирате отново файловете от дръпнатия пакет или да се посъветвате с пълните
                         <a href="http://dokuwiki.org/install">Инструкции за инсталация на Dokuwiki </a>';
$lang['i_funcna']                = 'PHP функцията <code>%s</code> не е достъпна. Може би доставчика на хостинг я е изключил';
$lang['i_phpver']                = 'Вашата PHP версия <code>%s</code> е по-стара от нужната <code>%s</code>. Трябва да обновите вашата PHP инсталация.';
$lang['i_permfail']              = '<code>%s</code> не е достъпна за писане от DokuWiki. Трябва да промените настройките за достъп до директорията!';
$lang['i_confexists']            = '<code>%s</code> вече съществува';
$lang['i_writeerr']              = '<code>%s</code> не можа да бъде създаден. Трябва да проверите правата на директорията/файла за достъп и да създадете файлът ръчно';
$lang['i_badhash']               = 'неразпознат или променен dokuwiki.php (hash=<code>%s</code>)';
$lang['i_badval']                = '<code>%s</code> - непозволена или празна стойност';
$lang['i_success']               = 'Настройката приключи успешно. Може да създадете файлът install.php сега. Продължете към
                        <a href="doku.php">Ново Ви DokuWiki</a>.';
$lang['i_failure']               = 'Имаше грешки при записа на файловете с настройки. Може да трябва да ги редактирате ръчно
                         може да използвате <a href="doku.php">Ново Ви DokuWiki</a>.';
$lang['i_policy']                = 'Първоначална политика достъп(ACL policy)';
$lang['i_pol0']                  = 'Отворено Уики (четене, писане, качване от всички)';
$lang['i_pol1']                  = 'Публично Уики (четене от всички, писане и качване от регистрирани потребители)';
$lang['i_pol2']                  = 'Затворено Wiki (четене, писане, качване само от регистрирани потребители)';
$lang['i_retry']                 = 'Отново';
